cd %SRC_DIR%\build
set DESTDIR=C:\clangb
:: Drop drive letter and colon
SET _PREFIX=%PREFIX:~2%
ninja install

pushd %DESTDIR%%_PREFIX%\Library
  if %PKG_NAME%==libclang-cpp (
    copy lib\%PKG_NAME%%SHLIB_EXT% %LIBRARY_LIB%
  ) else (
    copy lib\libclang-cpp.*.* %LIBRARY_LIB%
  )
popd
